@@ -661,9 +661,12 @@ module Bluefin.Compound
 
     -- | The documentation for 'Handle' shows how to use
     -- @OneWayCoercible@ to define @Handle@ instances.
-    OneWayCoercible.OneWayCoercible(OneWayCoercible.oneWayCoercibleImpl),
-    OneWayCoercibleHandle(MkOneWayCoercibleHandle),
+    OneWayCoercible.OneWayCoercible (OneWayCoercible.oneWayCoercibleImpl),
+    OneWayCoercibleHandle (MkOneWayCoercibleHandle),
+    handleOneWayCoercible,
     OneWayCoercible.gOneWayCoercible,
+    oneWayCoercibleTrustMe,
+    -- | Bluefin re-exports @Generic@ for convenience.
     OneWayCoercible.Generic,
 
     -- ** Other functions for compound effects
